import { Bounds, IControl, IIconFontGlyph, IImage, ILayer, ILngLat, IMapService, IMarker, IMarkerLayer, IPoint, IPopup, IPostProcessingPass, ISceneConfig, Point } from '@antv/l7-core';
import ILayerManager from './ILayerManager';
import IMapController from './IMapController';
import IPostProcessingPassPluggable from './IPostProcessingPassPluggable';
/**
 * 暴露 Scene API
 *
 * @example
 * import { Scene } from 'l7/scene';
 * import { PointLayer } from 'l7/layers';
 *
 * const scene = new Scene();
 * const pointLayer = new PointLayer();
 * scene.addLayer(pointLayer);
 *
 */
declare class Scene implements IPostProcessingPassPluggable, IMapController, ILayerManager {
    private sceneService;
    private mapService;
    private controlService;
    private layerService;
    private iconService;
    private markerService;
    private popupService;
    private fontService;
    private container;
    constructor(config: ISceneConfig);
    getMapService(): IMapService<unknown>;
    exportPng(type?: 'png' | 'jpg'): string;
    exportMap(type?: 'png' | 'jpg'): string;
    get map(): unknown;
    addLayer(layer: ILayer): void;
    getLayers(): ILayer[];
    getLayer(id: string): ILayer | undefined;
    getLayerByName(name: string): ILayer | undefined;
    removeLayer(layer: ILayer): void;
    removeAllLayer(): void;
    render(): void;
    addImage(id: string, img: IImage): void;
    hasImage(id: string): void;
    removeImage(id: string): void;
    addIconFontGlyphs(fontFamily: string, glyphs: IIconFontGlyph[]): void;
    addControl(ctr: IControl): void;
    removeControl(ctr: IControl): void;
    getControlByName(name: string): IControl | undefined;
    addMarker(marker: IMarker): void;
    addMarkerLayer(layer: IMarkerLayer): void;
    removeMarkerLayer(layer: IMarkerLayer): void;
    removeAllMakers(): void;
    addPopup(popup: IPopup): void;
    on(type: string, handle: (...args: any[]) => void): void;
    off(type: string, handle: (...args: any[]) => void): void;
    getZoom(): number;
    getCenter(): ILngLat;
    setCenter(center: [number, number]): void;
    getPitch(): number;
    setPitch(pitch: number): void;
    getRotation(): number;
    getBounds(): Bounds;
    setRotation(rotation: number): void;
    zoomIn(): void;
    zoomOut(): void;
    panTo(p: Point): void;
    panBy(pixel: Point): void;
    setZoom(zoom: number): void;
    fitBounds(bound: Bounds): void;
    setZoomAndCenter(zoom: number, center: Point): void;
    setMapStyle(style: any): void;
    pixelToLngLat(pixel: Point): ILngLat;
    lngLatToPixel(lnglat: Point): IPoint;
    containerToLngLat(pixel: Point): ILngLat;
    lngLatToContainer(lnglat: Point): IPoint;
    destroy(): void;
    registerPostProcessingPass(constructor: new (...args: any[]) => IPostProcessingPass<unknown>, name: string): void;
    private initComponent;
    private initControl;
}
export { Scene };
